@@ -52,6 +52,40 @@ QString shellQuote(const QString &path)
     escaped.replace('"', "\\\"");
     return '"' + escaped + '"';
 }
+
+bool isArchLinuxHost()
+{
+    if (QFile::exists("/etc/arch-release")) {
+        return true;
+    }
+
+    QFile osRelease("/etc/os-release");
+    if (!osRelease.open(QIODevice::ReadOnly | QIODevice::Text)) {
+        return false;
+    }
+
+    const QString data = QString::fromUtf8(osRelease.readAll());
+    QString id;
+    QString idLike;
+    const auto lines = data.split('\n');
+    for (const auto &line : lines) {
+        if (line.startsWith("ID=")) {
+            id = line.mid(3).trimmed();
+        } else if (line.startsWith("ID_LIKE=")) {
+            idLike = line.mid(8).trimmed();
+        }
+    }
+
+    auto normalize = [](QString value) {
+        value.remove('"');
+        return value.toLower();
+    };
+
+    id = normalize(id);
+    idLike = normalize(idLike);
+
+    return id == "arch" || idLike.split(' ').contains("arch");
+}
 }
 
 MainWindow::MainWindow(QWidget *parent)
@@ -164,6 +198,12 @@ void MainWindow::setup()
         ui->groupBoxUsage->hide();
     }
 
+    isArchLinux = isArchLinuxHost();
+    if (isArchLinux) {
+        ui->groupBoxKernel->hide();
+        ui->groupBoxApt->setTitle(tr("Clean pacman cache"));
+    }
+
     suppressUserSwitch = true;
 
     currentUser = cmdOut("logname", false, true);
@@ -515,13 +555,23 @@ void MainWindow::removeKernelPackages(const QStringList &list)
                         + R"( | tr '\n' ' ')");
     }
 
-    QString helper {"/usr/lib/" + QApplication::applicationName() + "/helper-terminal"};
+    QString helper {"/usr/lib/" + QApplication::applicationName() + "/helper-terminal-keep-open"};
+    QStringList packages;
+    packages << headers_installed << list;
+    if (!common.isEmpty()) {
+        packages << common.split(' ', Qt::SkipEmptyParts);
+    }
+    
     QString terminalCmd
-        = QString("%1 apt purge %2 %3 %4; apt-get install -f; read -n1 -srp \"%5\"")
-              .arg(rmOldVersions, headers_installed.join(' '), list.join(' '), common, tr("Press any key to close"));
+        = QString("%1 apt-get purge %2; apt-get install -f")
+              .arg(rmOldVersions, packages.join(' '));
     QProcess terminalProc;
     terminalProc.start("x-terminal-emulator", {"-e", "pkexec", helper, terminalCmd});
-    terminalProc.waitForFinished();
+    terminalProc.waitForFinished(-1);  // Wait indefinitely for terminal to close
+    if (terminalProc.state() == QProcess::Running) {
+        terminalProc.kill();
+        terminalProc.waitForFinished();
+    }
     setCursor(QCursor(Qt::ArrowCursor));
 }
 
@@ -679,7 +729,11 @@ void MainWindow::saveSchedule(const QString &cmd_str, const QString &period)
         }
 
         QTemporaryFile tempCron;
-        tempCron.open();
+        if (!tempCron.open()) {
+            QMessageBox::critical(this, tr("Error"),
+                                  tr("Failed to create temporary cron file: %1").arg(tempCron.errorString()));
+            return;
+        }
         tempCron.write(QString("@reboot root %1\n").arg(scriptTarget).toUtf8());
         tempCron.close();
         cmdOutAsRoot("mv " + tempCron.fileName() + ' ' + cronTarget);
@@ -688,7 +742,11 @@ void MainWindow::saveSchedule(const QString &cmd_str, const QString &period)
     }
 
     QTemporaryFile tempFile;
-    tempFile.open();
+    if (!tempFile.open()) {
+        QMessageBox::critical(this, tr("Error"),
+                              tr("Failed to create temporary script file: %1").arg(tempFile.errorString()));
+        return;
+    }
     QTextStream out(&tempFile);
     out << "#!/bin/sh\n";
     out << "#\n";
@@ -963,14 +1021,26 @@ void MainWindow::pushApply_clicked()
     };
     if (ui->groupBoxApt->isChecked()) {
         QString cleanCmd;
-        if (ui->radioAutoClean->isChecked()) {
-            cleanCmd = "apt-get autoclean";
-        } else if (ui->radioClean->isChecked()) {
-            cleanCmd = "apt-get clean";
+        QString size_cmd;
+        QString cacheLabel = "apt-cache";
+        if (isArchLinux) {
+            cacheLabel = "pacman-cache";
+            size_cmd = "du -s /var/cache/pacman/pkg/ | cut -f1";
+            if (ui->radioAutoClean->isChecked()) {
+                cleanCmd = "pacman -Sc --noconfirm";
+            } else if (ui->radioClean->isChecked()) {
+                cleanCmd = "pacman -Scc --noconfirm";
+            }
+        } else {
+            size_cmd = "du -s /var/cache/apt/archives/ | cut -f1";
+            if (ui->radioAutoClean->isChecked()) {
+                cleanCmd = "apt-get autoclean";
+            } else if (ui->radioClean->isChecked()) {
+                cleanCmd = "apt-get clean";
+            }
         }
 
         if (!cleanCmd.isEmpty()) {
-            const QString size_cmd = "du -s /var/cache/apt/archives/ | cut -f1";
             quint64 before_size = cmdOutAsRoot(size_cmd).toULongLong();
 
             if (!ui->radioReboot->isChecked()) {
@@ -978,7 +1048,7 @@ void MainWindow::pushApply_clicked()
             }
 
             quint64 after_size = cmdOutAsRoot(size_cmd).toULongLong();
-            addToTotal("apt-cache", before_size > after_size ? before_size - after_size : 0);
+            addToTotal(cacheLabel, before_size > after_size ? before_size - after_size : 0);
             addCommandToSchedule(cleanCmd);
         }
     }
@@ -1281,23 +1351,39 @@ void MainWindow::pushRTLremove_clicked()
         if ! lsmod | grep -q $module; then
             modname="${module}"
             [[ "${module}" != "rtl"* ]] && modname="rtl${module}"
-            echo -n "${modname}-dkms "
+            if dpkg -l "${modname}-dkms" 2>/dev/null | grep -q ^ii; then
+                echo -n "${modname}-dkms "
+            fi
         fi
     done
     if ! lsmod | grep -q -w ^wl
         then
-            echo -n broadcom-sta-dkms
+            if dpkg -l broadcom-sta-dkms 2>/dev/null | grep -q ^ii; then
+                echo -n broadcom-sta-dkms
+            fi
         else
             lspci -v  | grep -q "Kernel driver in use: wl"$ || \
             lsusb -tv | grep -q "Driver=wl, "               || \
-            echo -n broadcom-sta-dkms
-    fi)");
+            if dpkg -l broadcom-sta-dkms 2>/dev/null | grep -q ^ii; then
+                echo -n broadcom-sta-dkms
+            fi
+    fi)", false, true);  // Run as user, quiet mode
 
-    QString helper {"/usr/lib/" + QApplication::applicationName() + "/helper-terminal"};
-    QString terminalCmd
-        = QString("apt purge %1; apt-get install -f; read -n1 -srp \"%2\"").arg(dumpList, tr("Press any key to close"));
+    dumpList = dumpList.trimmed();
+    if (dumpList.isEmpty()) {
+        QMessageBox::information(this, tr("Info"), tr("No unused network drivers found to remove."));
+        setCursor(QCursor(Qt::ArrowCursor));
+        return;
+    }
+
+    QString helper {"/usr/lib/" + QApplication::applicationName() + "/helper-terminal-keep-open"};
+    QString terminalCmd = QString("apt-get purge %1; apt-get install -f").arg(dumpList);
     QProcess terminalProc;
     terminalProc.start("x-terminal-emulator", {"-e", "pkexec", helper, terminalCmd});
-    terminalProc.waitForFinished();
+    terminalProc.waitForFinished(-1);  // Wait indefinitely for terminal to close
+    if (terminalProc.state() == QProcess::Running) {
+        terminalProc.kill();
+        terminalProc.waitForFinished();
+    }
     setCursor(QCursor(Qt::ArrowCursor));
 }
