@@ -3,112 +3,94 @@
     <name>MainWindow</name>
     <message>
         <location filename="../mainwindow.ui" line="14"/>
-        <location filename="../mainwindow.cpp" line="150"/>
-        <location filename="../mainwindow.cpp" line="1143"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="565"/>
+        <location filename="../mainwindow.cpp" line="184"/>
+        <location filename="../mainwindow.cpp" line="1218"/>
         <source>MX Cleanup</source>
         <translation>MX Nettoyage - MX Cleanup</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="683"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="619"/>
         <source>Display help </source>
         <translation>Afficher l’aide </translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="686"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="621"/>
         <source>Help</source>
         <translation>Aide</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="692"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="623"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="658"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="612"/>
         <source>About this application</source>
         <translation>À propos de cette application</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="24"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="603"/>
         <source>Main</source>
         <translation>Principal</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="531"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="602"/>
         <source>Purge residual configurations from removed packages</source>
         <translation>Purger les configurations résiduelles des paquets supprimés</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="539"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="610"/>
         <source>Tools</source>
         <translation>Outils </translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="545"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="604"/>
         <source>Removal Tools</source>
         <translation>Outil de suppression</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="583"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="607"/>
         <source>Remove MX manuals for languages other than system default</source>
         <translation>Supprimer les manuels MX pour les langues autres que la langue par défaut du système</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="661"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="614"/>
         <source>About...</source>
         <translation>À propos…</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="667"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="616"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="781"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="631"/>
         <source>Quit application</source>
         <translation>Quitter l’application</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="784"/>
-        <location filename="../mainwindow.cpp" line="1244"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="633"/>
+        <location filename="../mainwindow.cpp" line="1319"/>
         <source>Close</source>
         <translation>Quitter</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="790"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="635"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="756"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="626"/>
         <source>Apply</source>
         <translation>Appliquer</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="36"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="566"/>
         <source>Empty Trash</source>
         <translation>Vider la corbeille</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="45"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="567"/>
         <source>Trash older than:</source>
         <translation>Poubelle plus vieille que :</translation>
     </message>
@@ -116,300 +98,288 @@
         <location filename="../mainwindow.ui" line="103"/>
         <location filename="../mainwindow.ui" line="294"/>
         <location filename="../mainwindow.ui" line="438"/>
-        <location filename="../mainwindow.cpp" line="828"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="570"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="584"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="592"/>
+        <location filename="../mainwindow.cpp" line="891"/>
         <source> days</source>
         <translation> jours</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="58"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="568"/>
         <source>All users</source>
         <translation>Tous les utilisateurs</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="90"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="569"/>
         <source>Selected user</source>
         <translation>Utilisateur sélectionné</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="210"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="579"/>
         <source>Clear APT Cache</source>
         <translation>Vider le cache APT</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="225"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="580"/>
         <source>Old files</source>
         <translation>Anciens fichiers</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="244"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="581"/>
         <source>All files</source>
         <translation>Tous les fichiers</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="605"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="608"/>
         <source>Graphical Tool for Analyzing Disk Usage</source>
         <translation>Outil graphique d’analyse de l’utilisation du disque</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="617"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="609"/>
         <source>Run Disk Usage Analyzer</source>
         <translation>Lancer l’analyse de l’utilisation du disque</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="141"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="573"/>
         <source>Schedule</source>
         <translation>Programme</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="153"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="574"/>
         <source>No automatic clean</source>
         <translation>Pas de nettoyage automatique</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="160"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="575"/>
         <source>At reboot</source>
         <translation>Au redémarrage</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="167"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="576"/>
         <source>Daily</source>
         <translation>Quotidien</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="174"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="577"/>
         <source>Weekly</source>
         <translation>Hebdomadaire</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="181"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="578"/>
         <source>Monthly</source>
         <translation>Mensuel</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="467"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="594"/>
         <source>Free Disk Space for User</source>
         <translation>Espace disque libre de l’utilisateur</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="479"/>
         <location filename="../mainwindow.ui" line="495"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="596"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="600"/>
         <source>Select user to repair</source>
         <translation>Choisir l’utilisateur à modifier ou à réparer</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="482"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="598"/>
         <source>Select user:</source>
         <translation>Choisir l’utilisateur :</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="263"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="582"/>
         <source>Delete Logs</source>
         <translation>Supprimer les journaux - logs</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="278"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="583"/>
         <source>All logs</source>
         <translation>Tous les journaux - logs</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="339"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="587"/>
         <source>Old logs</source>
         <translation>Anciens journaux - logs</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="326"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="586"/>
         <source>Logs older than:</source>
         <translation>Journaux - logs plus vieux que :</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="551"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="605"/>
         <source>Remove unused WiFi drivers</source>
         <translation>Supprimer les pilotes WiFi inutilisés</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="570"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="606"/>
         <source>List and select kernels to remove</source>
         <translation>Lister et sélectionner les noyaux à supprimer</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="125"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="571"/>
         <source>Clean Flatpak</source>
         <translation>Flatpak à nettoyer</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="131"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="572"/>
         <source>Remove unused runtimes</source>
         <translation>Suppression des runtimes « environnements d’exécution » inutilisés</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="364"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="588"/>
         <source>Clean Folders</source>
         <translation>Dossiers à nettoyer</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="428"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="591"/>
         <source>Not accessed for:</source>
         <translation>Non consulté depuis :</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="376"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="589"/>
         <source>Cache</source>
         <translation>Cache</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="451"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="593"/>
         <source>All (potentially dangerous)</source>
         <translation>Tout (potentiellement dangereux)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="405"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="590"/>
         <source>Thumbnails</source>
         <translation>Images miniatures - thumbnails</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="101"/>
+        <location filename="../mainwindow.cpp" line="135"/>
         <source>Remove Manuals</source>
         <translation>Supprimer les manuels</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="101"/>
+        <location filename="../mainwindow.cpp" line="135"/>
         <source>No manuals to remove.</source>
         <translation>Aucun manuel à supprimer.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="108"/>
+        <location filename="../mainwindow.cpp" line="142"/>
         <source>Removing packages, please wait</source>
         <translation>Suppression des paquets, veuillez patienter</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="515"/>
-        <location filename="../mainwindow.cpp" line="1289"/>
-        <source>Press any key to close</source>
-        <translation>Appuyez sur une touche pour fermer</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="828"/>
+        <location filename="../mainwindow.cpp" line="891"/>
         <source> day</source>
         <translation> jour</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="845"/>
+        <location filename="../mainwindow.cpp" line="729"/>
+        <location filename="../mainwindow.cpp" line="742"/>
+        <location filename="../mainwindow.cpp" line="908"/>
         <source>Error</source>
         <translation>Erreur</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="845"/>
+        <location filename="../mainwindow.cpp" line="204"/>
+        <source>Clean pacman cache</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="730"/>
+        <source>Failed to create temporary cron file: %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="743"/>
+        <source>Failed to create temporary script file: %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="908"/>
         <source>Failed to elevate privileges</source>
         <translation>L’élévation des privilèges a échoué</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1131"/>
+        <location filename="../mainwindow.cpp" line="1206"/>
         <source>Done</source>
         <translation>Terminé</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1133"/>
+        <location filename="../mainwindow.cpp" line="1208"/>
         <source>Cleanup script will run at reboot</source>
         <translation>Le script de nettoyage s’exécutera au redémarrage</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1134"/>
+        <location filename="../mainwindow.cpp" line="1209"/>
         <source>Cleanup command done</source>
         <translation>Commande de nettoyage exécutée</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1135"/>
+        <location filename="../mainwindow.cpp" line="1210"/>
         <source>%1 MiB were freed</source>
         <translation>%1 Mio sont de nouveau disponibles</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1143"/>
+        <location filename="../mainwindow.cpp" line="1218"/>
         <source>About</source>
         <translation>À propos</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1144"/>
+        <location filename="../mainwindow.cpp" line="1219"/>
         <source>Version: </source>
         <translation>Version : </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1146"/>
+        <location filename="../mainwindow.cpp" line="1221"/>
         <source>Quick and safe removal of old files</source>
         <translation>Suppression rapide et sûre des anciens fichiers</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1148"/>
+        <location filename="../mainwindow.cpp" line="1223"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1149"/>
+        <location filename="../mainwindow.cpp" line="1224"/>
         <source>%1 License</source>
         <translation>%1 Licence</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1156"/>
+        <location filename="../mainwindow.cpp" line="1231"/>
         <source>%1 Help</source>
         <translation>%1 Aide</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1239"/>
+        <location filename="../mainwindow.cpp" line="1314"/>
         <source>Kernel currently in use: &lt;b&gt;%1&lt;/b&gt;</source>
         <translation>Noyau utilisé actuellement : &lt;b&gt;%1&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1242"/>
+        <location filename="../mainwindow.cpp" line="1317"/>
         <source>Remove selected</source>
         <translation>Supprimer le(s) sélectionné(s)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1247"/>
+        <location filename="../mainwindow.cpp" line="1322"/>
         <source>Similar kernels that can be removed:</source>
         <translation>Noyaux similaires qui peuvent être supprimés :</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1248"/>
+        <location filename="../mainwindow.cpp" line="1323"/>
         <source>Other kernels that can be removed:</source>
         <translation>Autres noyaux qui peuvent être supprimés :</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1251"/>
+        <location filename="../mainwindow.cpp" line="1326"/>
         <source>&lt;b&gt;Nothing to remove.&lt;/b&gt; Cannot remove kernel in use.</source>
         <translation>&lt;b&gt;Rien à supprimer.&lt;/b&gt; Impossible de retirer le noyau en cours d’utilisation.</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="1370"/>
+        <source>Info</source>
+        <translation>Info</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="1370"/>
+        <source>No unused network drivers found to remove.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>QObject</name>
