@@ -3,112 +3,94 @@
     <name>MainWindow</name>
     <message>
         <location filename="../mainwindow.ui" line="14"/>
-        <location filename="../mainwindow.cpp" line="150"/>
-        <location filename="../mainwindow.cpp" line="1143"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="565"/>
+        <location filename="../mainwindow.cpp" line="184"/>
+        <location filename="../mainwindow.cpp" line="1218"/>
         <source>MX Cleanup</source>
         <translation>Limpeza Automática do MX</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="683"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="619"/>
         <source>Display help </source>
         <translation>Exibir ajuda</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="686"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="621"/>
         <source>Help</source>
         <translation>Ajuda</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="692"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="623"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="658"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="612"/>
         <source>About this application</source>
         <translation>Sobre este programa</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="24"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="603"/>
         <source>Main</source>
         <translation>Principais</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="531"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="602"/>
         <source>Purge residual configurations from removed packages</source>
         <translation>Limpar as configurações residuais dos pacotes que foram removidos</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="539"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="610"/>
         <source>Tools</source>
         <translation>Ferramentas</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="545"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="604"/>
         <source>Removal Tools</source>
         <translation>Ferramenta de Remoção</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="583"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="607"/>
         <source>Remove MX manuals for languages other than system default</source>
         <translation>Remover os manuais do MX dos idiomas diferentes do padrão do sistema operacional</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="661"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="614"/>
         <source>About...</source>
         <translation>Sobre...</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="667"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="616"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="781"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="631"/>
         <source>Quit application</source>
         <translation>Sair do programa</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="784"/>
-        <location filename="../mainwindow.cpp" line="1244"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="633"/>
+        <location filename="../mainwindow.cpp" line="1319"/>
         <source>Close</source>
         <translation>Fechar</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="790"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="635"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="756"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="626"/>
         <source>Apply</source>
         <translation>Aplicar</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="36"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="566"/>
         <source>Empty Trash</source>
         <translation>Esvaziar a Lixeira</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="45"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="567"/>
         <source>Trash older than:</source>
         <translation>A lixeira está com mais de:</translation>
     </message>
@@ -116,300 +98,288 @@
         <location filename="../mainwindow.ui" line="103"/>
         <location filename="../mainwindow.ui" line="294"/>
         <location filename="../mainwindow.ui" line="438"/>
-        <location filename="../mainwindow.cpp" line="828"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="570"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="584"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="592"/>
+        <location filename="../mainwindow.cpp" line="891"/>
         <source> days</source>
         <translation>dias</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="58"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="568"/>
         <source>All users</source>
         <translation>Todos os usuários</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="90"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="569"/>
         <source>Selected user</source>
         <translation>Usuário selecionado</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="210"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="579"/>
         <source>Clear APT Cache</source>
         <translation>Limpar a memória cache do APT</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="225"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="580"/>
         <source>Old files</source>
         <translation>Arquivos antigos</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="244"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="581"/>
         <source>All files</source>
         <translation>Todos os arquivos</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="605"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="608"/>
         <source>Graphical Tool for Analyzing Disk Usage</source>
         <translation>Ferramenta Gráfica para Analisar a Utilização do Disco</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="617"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="609"/>
         <source>Run Disk Usage Analyzer</source>
         <translation>Executar o Analisador de Utilização do Disco</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="141"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="573"/>
         <source>Schedule</source>
         <translation>Agendar a limpeza automática</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="153"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="574"/>
         <source>No automatic clean</source>
         <translation>Não fazer a limpeza automática</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="160"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="575"/>
         <source>At reboot</source>
         <translation>Na reinicialização</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="167"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="576"/>
         <source>Daily</source>
         <translation>Diariamente</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="174"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="577"/>
         <source>Weekly</source>
         <translation>Semanalmente</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="181"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="578"/>
         <source>Monthly</source>
         <translation>Mensalmente</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="467"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="594"/>
         <source>Free Disk Space for User</source>
         <translation>Espaço Livre em Disco para o Usuário</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="479"/>
         <location filename="../mainwindow.ui" line="495"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="596"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="600"/>
         <source>Select user to repair</source>
         <translation>Selecione o usuário para ser reparado</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="482"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="598"/>
         <source>Select user:</source>
         <translation>Selecione o usuário:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="263"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="582"/>
         <source>Delete Logs</source>
         <translation>Eliminar os Registros</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="278"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="583"/>
         <source>All logs</source>
         <translation>Todos os registros</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="339"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="587"/>
         <source>Old logs</source>
         <translation>Registros antigos</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="326"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="586"/>
         <source>Logs older than:</source>
         <translation>Os registros (logs) estão com mais de:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="551"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="605"/>
         <source>Remove unused WiFi drivers</source>
         <translation>Remova os controladores das placas de redes sem fio ou Wi-Fi que não estão sendo utilizados</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="570"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="606"/>
         <source>List and select kernels to remove</source>
         <translation>Listar e selecionar os núcleos (kernels) para serem removidos</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="125"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="571"/>
         <source>Clean Flatpak</source>
         <translation>Limpeza de Flatpak</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="131"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="572"/>
         <source>Remove unused runtimes</source>
         <translation>Remover o ‘runtimes’ (ambiente de tempo de execução) que não estiver sendo utilizado</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="364"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="588"/>
         <source>Clean Folders</source>
         <translation>Limpar as Pastas </translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="428"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="591"/>
         <source>Not accessed for:</source>
         <translation>Não foi acessado para:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="376"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="589"/>
         <source>Cache</source>
         <translation>Área Temporária da Memória</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="451"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="593"/>
         <source>All (potentially dangerous)</source>
         <translation>Todos (potencialmente perigosos)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="405"/>
-        <location filename="../build/mx-cleanup_autogen/include/ui_mainwindow.h" line="590"/>
         <source>Thumbnails</source>
         <translation>Miniatura</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="101"/>
+        <location filename="../mainwindow.cpp" line="135"/>
         <source>Remove Manuals</source>
         <translation>Remover os Manuais</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="101"/>
+        <location filename="../mainwindow.cpp" line="135"/>
         <source>No manuals to remove.</source>
         <translation>Não existem manuais para serem removidos.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="108"/>
+        <location filename="../mainwindow.cpp" line="142"/>
         <source>Removing packages, please wait</source>
         <translation>Removendo os pacotes. Por favor, aguarde a finalização</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="515"/>
-        <location filename="../mainwindow.cpp" line="1289"/>
-        <source>Press any key to close</source>
-        <translation>Pressione qualquer tecla para fechar</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="828"/>
+        <location filename="../mainwindow.cpp" line="891"/>
         <source> day</source>
         <translation>dia</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="845"/>
+        <location filename="../mainwindow.cpp" line="729"/>
+        <location filename="../mainwindow.cpp" line="742"/>
+        <location filename="../mainwindow.cpp" line="908"/>
         <source>Error</source>
         <translation>Ocorreu um erro</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="845"/>
+        <location filename="../mainwindow.cpp" line="204"/>
+        <source>Clean pacman cache</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="730"/>
+        <source>Failed to create temporary cron file: %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="743"/>
+        <source>Failed to create temporary script file: %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="908"/>
         <source>Failed to elevate privileges</source>
         <translation>Ocorreu uma falha ao elevar os privilégios</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1131"/>
+        <location filename="../mainwindow.cpp" line="1206"/>
         <source>Done</source>
         <translation>Concluído</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1133"/>
+        <location filename="../mainwindow.cpp" line="1208"/>
         <source>Cleanup script will run at reboot</source>
         <translation>O programa de limpeza automática será executado na reinicialização</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1134"/>
+        <location filename="../mainwindow.cpp" line="1209"/>
         <source>Cleanup command done</source>
         <translation>O comando da limpeza foi concluído com sucesso</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1135"/>
+        <location filename="../mainwindow.cpp" line="1210"/>
         <source>%1 MiB were freed</source>
         <translation>Foram liberados %1 MiB</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1143"/>
+        <location filename="../mainwindow.cpp" line="1218"/>
         <source>About</source>
         <translation>Sobre</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1144"/>
+        <location filename="../mainwindow.cpp" line="1219"/>
         <source>Version: </source>
         <translation>Versão:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1146"/>
+        <location filename="../mainwindow.cpp" line="1221"/>
         <source>Quick and safe removal of old files</source>
         <translation>Remoção rápida e segura de arquivos antigos</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1148"/>
+        <location filename="../mainwindow.cpp" line="1223"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Direitos de Autor (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1149"/>
+        <location filename="../mainwindow.cpp" line="1224"/>
         <source>%1 License</source>
         <translation>Licença do %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1156"/>
+        <location filename="../mainwindow.cpp" line="1231"/>
         <source>%1 Help</source>
         <translation>Ajuda do %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1239"/>
+        <location filename="../mainwindow.cpp" line="1314"/>
         <source>Kernel currently in use: &lt;b&gt;%1&lt;/b&gt;</source>
         <translation>O núcleo (kernel) atualmente em uso é &lt;b&gt;%1&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1242"/>
+        <location filename="../mainwindow.cpp" line="1317"/>
         <source>Remove selected</source>
         <translation>Remover os itens selecionados</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1247"/>
+        <location filename="../mainwindow.cpp" line="1322"/>
         <source>Similar kernels that can be removed:</source>
         <translation>Os núcleos (kernels) similares que podem ser removidos:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1248"/>
+        <location filename="../mainwindow.cpp" line="1323"/>
         <source>Other kernels that can be removed:</source>
         <translation>Outros núcleos (kernels) que podem ser removidos:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1251"/>
+        <location filename="../mainwindow.cpp" line="1326"/>
         <source>&lt;b&gt;Nothing to remove.&lt;/b&gt; Cannot remove kernel in use.</source>
         <translation>&lt;b&gt;Este núcleo pode ser removido.&lt;/b&gt; Não é possível remover o núcleo (kernel) que está em uso.</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="1370"/>
+        <source>Info</source>
+        <translation>Informações</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="1370"/>
+        <source>No unused network drivers found to remove.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>QObject</name>
